Lulu
====

.. image:: https://travis-ci.org/iawia002/Lulu.svg?branch=master
    :target: https://travis-ci.org/iawia002/Lulu

`Lulu <https://github.com/iawia002/Lulu>`__ is a friendly you-get fork (⏬ Dumb downloader that scrapes the web)

.. code:: console

    $ lulu https://www.bilibili.com/video/av18295259/
    site:                Bilibili
    title:               【中文八级】俄罗斯人的名字超乎你的想象
    stream:
    - format:        flv720
      container:     flv
      size:          175.4 MiB (183914793 bytes)
    # download-with: lulu --format=flv720 [URL]

    Downloading 【中文八级】俄罗斯人的名字超乎你的想象.flv ...
    100% (175.4/175.4MB) ├████████████████████████████████████████┤[1/1]    3 MB/s

    Downloading 【中文八级】俄罗斯人的名字超乎你的想象.cmt.xml ...
